@@ -2,4 +2,4 @@
 
 from CRTK.contract import Contract 
 from CRTK.runtimecontract import RuntimeContract
-from CRTK.utilities import *
\ No newline at end of file
+from CRTK import utilities
\ No newline at end of file
