@@ -35,6 +35,13 @@ class Contract(object):
     def get_function_signature_list(self):
         return self.function_signatures
 
+    def get_opcode_occurrence(self, collapse=0):
+        opcode_list = [item[2] for item in self.opcode]
+        return opcode_occurrence(opcode_list, collapse)
+
+    def get_address(self):
+        return self.address
+
     def is_ERC20(self):
         return self.ERC20
 
@@ -49,7 +56,3 @@ class Contract(object):
 
     def is_real_contract(self):
         return self.real_contract
-
-    def get_opcode_occurrence(self, collapse=0):
-        opcode_list = [item[2] for item in self.opcode]
-        return opcode_occurrence(opcode_list, collapse)
